@@ -84,6 +84,7 @@ class AnalysisForm(forms.Form):
     numSylls = forms.BooleanField(initial=True,required=False,label='Number of syllables')
     prev_sem_pred = forms.BooleanField(initial=True,required=False,label='Previous semantic predictability')
     foll_sem_pred = forms.BooleanField(initial=True,required=False,label='Following semantic predictability')
+    pause_dist = forms.BooleanField(initial=True,required=False,label='Distance to pauses')
     #force_fetch = forms.CharField(label='Force fetch')
     #force_fetch.widget = forms.CheckboxSelectMultiple(choices=FETCH_CHOICES)
 
@@ -109,7 +110,9 @@ class AnalysisForm(forms.Form):
                                  'contextProbs',
                                  'repetitions',
                                  'wasRepeated',
-                                 'semPred')}),
+                                 'prev_sem_pred',
+                                 'foll_sem_pred',
+                                 'pause_dist')}),
                      ('Speaker factors',
                       {'fields':('gender',
                                  'age',
