@@ -1111,6 +1111,12 @@ class WordToken(models.Model):
                 outline['ImmedFollSemPred'] = self.getImmediateFollSemPred()
                 outline['IntermedFollSemPred'] = self.getIntermedFollSemPred()
             wanted_fields.extend(['FollSemPred','ImmedFollSemPred','IntermedFollSemPred'])
+        if form['pause_dist']:
+            if 'DistFollPause' not in outline:
+                outline['DistFollPause'] = self.getFollDistToPause()
+            if 'DistPrevPause' not in outline:
+                outline['DistPrevPause'] = self.getPrevDistToPause()
+            wanted_fields.extend(['DistFollPause','DistPrevPause'])
         if form['placeInDialog']:
             if 'placeInDialog' not in outline:
                 outline['placeInDialog'] = self.getDialogPlace()
